@@ -1,16 +1,6 @@
 
 bootstrap <- function(version, library) {
 
-  # read repos (respecting override if set)
-  repos <- Sys.getenv("RENV_CONFIG_REPOS_OVERRIDE", unset = NA)
-  if (is.na(repos))
-    repos <- getOption("repos")
-
-  # fix up repos
-  on.exit(options(repos = repos), add = TRUE)
-  repos[repos == "@CRAN@"] <- "https://cloud.r-project.org"
-  options(repos = repos)
-
   # attempt to download renv
   tarball <- tryCatch(renv_bootstrap_download(version), error = identity)
   if (inherits(tarball, "error"))
@@ -23,6 +13,62 @@ bootstrap <- function(version, library) {
 
 }
 
+renv_bootstrap_repos <- function() {
+
+  # check for repos override
+  repos <- Sys.getenv("RENV_CONFIG_REPOS_OVERRIDE", unset = NA)
+  if (!is.na(repos))
+    return(repos)
+
+  # if we're testing, re-use the test repositories
+  if (renv_tests_running())
+    return(getOption("renv.tests.repos"))
+
+  # retrieve current repos
+  repos <- getOption("repos")
+
+  # ensure @CRAN@ entries are resolved
+  repos[repos == "@CRAN@"] <- "https://cloud.r-project.org"
+
+  # add in renv.bootstrap.repos if set
+  default <- c(CRAN = "https://cloud.r-project.org")
+  extra <- getOption("renv.bootstrap.repos", default = default)
+  repos <- c(repos, extra)
+
+  # remove duplicates that might've snuck in
+  dupes <- duplicated(repos) | duplicated(names(repos))
+  repos[!dupes]
+
+}
+
+renv_bootstrap_download <- function(version) {
+
+  # if the renv version number has 4 components, assume it must
+  # be retrieved via github
+  nv <- numeric_version(version)
+  components <- unclass(nv)[[1]]
+
+  methods <- if (length(components) == 4L) {
+    list(
+      renv_bootstrap_download_github
+    )
+  } else {
+    list(
+      renv_bootstrap_download_cran_latest,
+      renv_bootstrap_download_cran_archive
+    )
+  }
+
+  for (method in methods) {
+    path <- tryCatch(method(version), error = identity)
+    if (is.character(path) && file.exists(path))
+      return(path)
+  }
+
+  stop("failed to download renv ", version)
+
+}
+
 renv_bootstrap_download_impl <- function(url, destfile) {
 
   mode <- "wb"
@@ -44,32 +90,6 @@ renv_bootstrap_download_impl <- function(url, destfile) {
 
 }
 
-renv_bootstrap_download <- function(version) {
-
-  # if the renv version number has 4 components, assume it must
-  # be retrieved via github
-  nv <- numeric_version(version)
-  components <- unclass(nv)[[1]]
-
-  methods <- if (length(components) == 4L) {
-    list(renv_bootstrap_download_github)
-  } else {
-    list(
-      renv_bootstrap_download_cran_latest,
-      renv_bootstrap_download_cran_archive
-    )
-  }
-
-  for (method in methods) {
-    path <- tryCatch(method(version), error = identity)
-    if (is.character(path) && file.exists(path))
-      return(path)
-  }
-
-  stop("failed to download renv ", version)
-
-}
-
 renv_bootstrap_download_cran_latest <- function(version) {
 
   repos <- renv_bootstrap_download_cran_latest_find(version)
@@ -93,11 +113,7 @@ renv_bootstrap_download_cran_latest <- function(version) {
 
 renv_bootstrap_download_cran_latest_find <- function(version) {
 
-  # check for renv on CRAN matching this version
-  all <- unique(c(
-    getOption("repos"),
-    getOption("renv.bootstrap.repos", default = "https://cloud.r-project.org")
-  ))
+  all <- renv_bootstrap_repos()
 
   for (repos in all) {
 
@@ -125,7 +141,7 @@ renv_bootstrap_download_cran_latest_find <- function(version) {
 renv_bootstrap_download_cran_archive <- function(version) {
 
   name <- sprintf("renv_%s.tar.gz", version)
-  repos <- getOption("repos")
+  repos <- renv_bootstrap_repos()
   urls <- file.path(repos, "src/contrib/Archive/renv", name)
   destfile <- file.path(tempdir(), name)
 
@@ -248,6 +264,19 @@ renv_bootstrap_prefix <- function() {
 
 }
 
+renv_bootstrap_library_root_name <- function(project) {
+
+  # use project name as-is if requested
+  asis <- Sys.getenv("RENV_PATHS_LIBRARY_ROOT_ASIS", unset = "FALSE")
+  if (asis)
+    return(basename(project))
+
+  # otherwise, disambiguate based on project's path
+  id <- substring(renv_bootstrap_hash_text(project), 1L, 8L)
+  paste(basename(project), id, sep = "-")
+
+}
+
 renv_bootstrap_library_root <- function(project) {
 
   path <- Sys.getenv("RENV_PATHS_LIBRARY", unset = NA)
@@ -256,8 +285,7 @@ renv_bootstrap_library_root <- function(project) {
 
   path <- Sys.getenv("RENV_PATHS_LIBRARY_ROOT", unset = NA)
   if (!is.na(path)) {
-    id <- substring(renv_bootstrap_hash_text(project), 1L, 8L)
-    name <- paste(basename(project), id, sep = "-")
+    name <- renv_bootstrap_library_root_name(project)
     return(file.path(path, name))
   }
 
