@@ -49,7 +49,7 @@ load <- function(project = getwd(), quiet = FALSE) {
   renv_envvars_save()
 
   # load a minimal amount of state when testing
-  if (renv_testing()) {
+  if (renv_tests_running()) {
     renv_load_libpaths(project)
     return(invisible(project))
   }
@@ -249,7 +249,7 @@ renv_load_profile_impl <- function(profile) {
 
   fmt <- "error sourcing %s: %s"
   warningf(fmt, renv_path_pretty(profile), conditionMessage(status))
-  if (!renv_testing())
+  if (!renv_tests_running())
     writeLines(status$traceback, con = stderr())
 
   FALSE
@@ -402,9 +402,10 @@ renv_load_finish <- function(project, lockfile) {
 
 renv_load_report_project <- function(project) {
 
-  quiet <-
+  quiet <- config$startup.quiet() %||% (
     identical(renv_verbose(), FALSE) ||
     renv_session_quiet()
+  )
 
   if (!quiet) {
     fmt <- "* Project '%s' loaded. [renv %s]"
