@@ -182,7 +182,7 @@ renv_remotes_resolve_bitbucket <- function(entry) {
   origin <- renv_retrieve_origin(host)
   url <- sprintf(fmt, origin, user, repo, ref)
 
-  destfile <- renv_tempfile("renv-bitbucket-")
+  destfile <- renv_tempfile_path("renv-bitbucket-")
   download(url, destfile = destfile, type = "bitbucket", quiet = TRUE)
   json <- renv_json_read(file = destfile)
   sha <- json$hash
@@ -192,7 +192,7 @@ renv_remotes_resolve_bitbucket <- function(entry) {
   origin <- renv_retrieve_origin(host)
   url <- sprintf(fmt, origin, user, repo, ref)
 
-  destfile <- renv_tempfile("renv-description-")
+  destfile <- renv_tempfile_path("renv-description-")
   download(url, destfile = destfile, type = "bitbucket", quiet = TRUE)
   desc <- renv_dcf_read(destfile)
 
@@ -214,7 +214,7 @@ renv_remotes_resolve_bitbucket <- function(entry) {
 renv_remotes_resolve_repository <- function(entry, latest) {
 
   package <- entry$package
-  if (package %in% rownames(renv_installed_packages_base()))
+  if (package %in% renv_packages_base())
     return(renv_remotes_resolve_base(package))
 
   version <- entry$version
@@ -249,7 +249,7 @@ renv_remotes_resolve_github_sha_pull <- function(host, user, repo, pull) {
   fmt <- "%s/repos/%s/%s/pulls/%s"
   origin <- renv_retrieve_origin(host)
   url <- sprintf(fmt, origin, user, repo, pull)
-  jsonfile <- renv_tempfile("renv-json-")
+  jsonfile <- renv_tempfile_path("renv-json-")
   download(url, destfile = jsonfile, type = "github", quiet = TRUE)
   json <- renv_json_read(jsonfile)
   json$head$sha
@@ -262,7 +262,7 @@ renv_remotes_resolve_github_sha_ref <- function(host, user, repo, ref) {
   origin <- renv_retrieve_origin(host)
   url <- sprintf(fmt, origin, user, repo, ref %||% "master")
   headers <- c(Accept = "application/vnd.github.v2.sha")
-  shafile <- renv_tempfile("renv-sha-")
+  shafile <- renv_tempfile_path("renv-sha-")
   download(url, destfile = shafile, type = "github", quiet = TRUE, headers = headers)
   sha <- renv_file_read(shafile)
 
@@ -288,7 +288,7 @@ renv_remotes_resolve_github_description <- function(host, user, repo, subdir, sh
   fmt <- "%s/repos/%s/%s/contents/%s?ref=%s"
   origin <- renv_retrieve_origin(host)
   url <- sprintf(fmt, origin, user, repo, descpath, sha)
-  jsonfile <- renv_tempfile("renv-json-")
+  jsonfile <- renv_tempfile_path("renv-json-")
   download(url, destfile = jsonfile, type = "github", quiet = TRUE)
   json <- renv_json_read(jsonfile)
   contents <- renv_base64_decode(json$content)
@@ -297,7 +297,7 @@ renv_remotes_resolve_github_description <- function(host, user, repo, subdir, sh
   contents <- gsub("\r\n", "\n", contents, fixed = TRUE)
 
   # write to file and read back in
-  descfile <- renv_tempfile("renv-description-")
+  descfile <- renv_tempfile_path("renv-description-")
   writeLines(contents, con = descfile)
   renv_dcf_read(descfile)
 
@@ -323,7 +323,7 @@ renv_remotes_resolve_github_ref_impl <- function(host, user, repo) {
   url <- sprintf(fmt, origin, user, repo)
 
   # download JSON data at endpoint
-  jsonfile <- renv_tempfile("renv-github-ref-", fileext = ".json")
+  jsonfile <- renv_tempfile_path("renv-github-ref-", fileext = ".json")
   download(url, destfile = jsonfile, type = "github", quiet = TRUE)
   json <- renv_json_read(jsonfile)
 
@@ -382,9 +382,10 @@ renv_remotes_resolve_gitlab <- function(entry) {
   fmt <- "%s/api/v4/projects/%s/repository/commits/%s"
   origin <- renv_retrieve_origin(host)
   id <- URLencode(paste(user, repo, sep = "/"), reserved = TRUE)
+  ref <- URLencode(ref, reserved = TRUE)
   url <- sprintf(fmt, origin, id, ref)
 
-  destfile <- renv_tempfile("renv-gitlab-commits-")
+  destfile <- renv_tempfile_path("renv-gitlab-commits-")
   download(url, destfile = destfile, type = "gitlab", quiet = TRUE)
   json <- renv_json_read(file = destfile)
   sha <- json$id
@@ -395,7 +396,7 @@ renv_remotes_resolve_gitlab <- function(entry) {
   id <- URLencode(paste(user, repo, sep = "/"), reserved = TRUE)
   url <- sprintf(fmt, origin, id, descpath, ref)
 
-  destfile <- renv_tempfile("renv-description-")
+  destfile <- renv_tempfile_path("renv-description-")
   download(url, destfile = destfile, type = "gitlab", quiet = TRUE)
   desc <- renv_dcf_read(destfile)
 
@@ -416,7 +417,7 @@ renv_remotes_resolve_gitlab <- function(entry) {
 
 renv_remotes_resolve_url <- function(entry, quiet = FALSE) {
 
-  tempfile <- renv_tempfile("renv-url-")
+  tempfile <- renv_tempfile_path("renv-url-")
   writeLines(entry, con = tempfile)
   hash <- tools::md5sum(tempfile)
 
