@@ -272,6 +272,16 @@ renv_settings_impl <- function(name, validate, default, update) {
 #'
 #' }
 #'
+#' \item{\code{r.version}}{
+#'
+#'   The version of \R to encode within the lockfile. This can be set as a
+#'   project-specific option if you'd like to allow multiple users to use
+#'   the same \code{renv} project with different versions of \R. `renv` will
+#'   still warn the user if the major + minor version of \R used in a project
+#'   does not match what is encoded in the lockfile.
+#'
+#' }
+#'
 #' \item{\code{snapshot.type}}{
 #'
 #'   The type of snapshot to perform by default. See [snapshot] for more
@@ -349,6 +359,13 @@ settings <- list(
     update   = NULL
   ),
 
+  r.version = renv_settings_impl(
+    name     = "r.version",
+    validate = is.character,
+    default  = character(),
+    update   = NULL
+  ),
+
   snapshot.type = renv_settings_impl(
     name     = "snapshot.type",
     validate = c("all", "custom", "implicit", "explicit", "packrat", "simple"),
