@@ -1,4 +1,8 @@
 
+renv_template_create <- function(template) {
+  gsub("^\\n+|\\n+$", "", template)
+}
+
 renv_template_replace <- function(text, replacements) {
 
   enumerate(replacements, function(key, value) {
