@@ -173,7 +173,7 @@ catchall <- function(expr) {
 
 ask <- function(question, default = FALSE) {
 
-  if (renv_testing())
+  if (renv_tests_running())
     return(TRUE)
 
   if (!interactive())
@@ -389,3 +389,7 @@ memoize <- function(key, expr, envir) {
   envir[[key]] <- value
   value
 }
+
+nth <- function(x, i) {
+  x[[i]]
+}
