@@ -3,6 +3,9 @@ context("Bootstrap")
 
 test_that("we can bootstrap the current version of renv", {
 
+  skip_on_cran()
+  skip_on_ci()
+
   renv_tests_scope()
 
   library <- renv_libpaths_default()
@@ -14,6 +17,9 @@ test_that("we can bootstrap the current version of renv", {
 
 test_that("we can bootstrap an archived version of renv", {
 
+  skip_on_cran()
+  skip_on_ci()
+
   renv_tests_scope()
 
   library <- renv_libpaths_default()
@@ -24,27 +30,30 @@ test_that("we can bootstrap an archived version of renv", {
 })
 
 test_that("we can install a version of renv from GitHub", {
+
   skip_on_cran()
-  skip_on_appveyor()
+  skip_on_ci()
 
   renv_tests_scope()
 
   library <- renv_libpaths_default()
-  bootstrap(version = "0.9.3-10", library = library)
+  bootstrap(version = "0.12.3-1", library = library)
   expect_true(renv_package_installed("renv", library))
-  expect_true(renv_package_version("renv") == "0.9.3-10")
+  expect_true(renv_package_version("renv") == "0.12.3-1")
 
 })
 
 test_that("bootstrap succeeds with empty repos", {
+
   skip_on_cran()
-  skip_on_appveyor()
+  skip_on_os("windows")
 
   renv_tests_scope()
   renv_scope_options(repos = character())
 
   library <- renv_libpaths_default()
-  bootstrap(version = "0.12.2", library = library)
+  bootstrap(version = "1.0.0", library = library)
   expect_true(renv_package_installed("renv", library))
-  expect_true(renv_package_version("renv") == "0.12.2")
+  expect_true(renv_package_version("renv") == "1.0.0")
+
 })
