@@ -3,7 +3,7 @@ context("Restore")
 
 test_that("library permissions are validated before restore", {
   skip_on_os("windows")
-  inaccessible <- renv_tempfile()
+  inaccessible <- renv_tempfile_path()
   dir.create(inaccessible, mode = "0100")
   renv_scope_options(renv.verbose = FALSE)
   expect_false(renv_install_preflight_permissions(inaccessible))
@@ -79,31 +79,44 @@ test_that("install.staged works as expected", {
 
   renv_tests_scope("breakfast")
 
-  renv::init()
-  renv::remove("breakfast")
-  renv::purge("breakfast")
+  init()
+  library <- renv_paths_library(project = getwd())
 
   install.opts <- list(breakfast = "--version")
 
   local({
-    renv_scope_options(renv.config.install.staged = TRUE)
-    renv_scope_options(install.opts = install.opts)
-    templib <- tempfile("renv-templib-")
-    expect_error(renv::restore(library = templib))
-    files <- list.files(templib)
+
+    renv_scope_options(
+      renv.config.install.staged = TRUE,
+      renv.config.install.transactional = TRUE,
+      install.opts = install.opts
+    )
+
+    renv_scope_envvars(RENV_PATHS_CACHE = tempfile())
+
+    unlink(renv_paths_library(), recursive = TRUE)
+    expect_error(renv::restore())
+    files <- list.files(library)
     expect_true(length(files) == 0L)
+
   })
 
   local({
-    renv_scope_options(renv.config.install.staged = FALSE)
-    renv_scope_options(install.opts = install.opts)
-    templib <- tempfile("renv-templib-")
-    expect_error(renv::restore(library = templib))
-    files <- list.files(templib)
-    expect_true(length(files) != 0L)
-  })
 
-  install("breakfast")
+    renv_scope_options(
+      renv.config.install.staged = FALSE,
+      renv.config.install.transactional = FALSE,
+      install.opts = install.opts
+    )
+
+    renv_scope_envvars(RENV_PATHS_CACHE = tempfile())
+
+    unlink(renv_paths_library(), recursive = TRUE)
+    expect_error(renv::restore())
+    files <- list.files(library)
+    expect_true(length(files) != 0L)
+
+  })
 
 })
 
@@ -136,6 +149,8 @@ test_that("renv::restore(packages = <...>) works", {
 
 test_that("restore ignores packages of incompatible architecture", {
 
+  renv_scope_options(renv.tests.verbose = FALSE)
+
   renv_tests_scope(c("unixonly", "windowsonly"))
   renv::init()
 
